Dim oFileSystem
Dim oXSL
Dim sResultsDirectoryPath
Dim oSavedConfigs

Sub Window_OnLoad

	'Resize the window
	Window.ResizeTo 600,680

	'Load the saved configurations
	Set oSavedConfigs = CreateObject("MSXML.DOMDocument")
	oSavedConfigs.Load "Bin/Config.xml"

	'Load the style
	Set oSavedConfigStyle = CreateObject("MSXML.DOMDocument")
	oSavedConfigStyle.Load "Bin/Config_Style.xsl"

	'Transform the document and display the results
	Saved_Config.innerHTML = oSavedConfigs.TransformNode(oSavedConfigStyle)

	'Get rid of the style (we still need the configurations, however)
	Set oSavedConfigStyle = Nothing

End Sub


Function VerifyInput()

	WriteToLog "Initializing: " & Now()

	'Clear any previous error alerts
	ClearInputBackgrounds

	'Get a file system object
	Set oFileSystem = CreateObject("Scripting.FileSystemObject")
	WriteToLog "Created File System Object"
	WriteToLog ""

	'Clean up the input
	XSL_Stylesheet.value = Trim(Replace(XSL_Stylesheet.value,"/","\"))
	XML_Directory.value = Trim(Replace(XML_Directory.value,"/","\"))
	Results_Directory.value = Trim(Replace(Results_Directory.value,"/","\"))
	Index_XSL_Stylesheet.Value = Trim(Index_XSL_Stylesheet.Value)

	'Did the user specifiy an XML directory?
	If Len(XML_Directory.Value) < 1 Then

		'No, throw an error
		DisplayInputError "No XML directory was specified.","XML_Directory"
		VerifyInput = False
		Exit Function

	Else
	
		'Yes. Does the directory exist?
		If Not oFileSystem.FolderExists(XML_Directory.Value) Then

			'No, throw an error
			DisplayInputError "XML Directory """ & XML_Directory.Value & """ does not exist", "XML_Directory"
			VerifyInput = False
			Exit Function

		End If

	End If

	'Did the user specify an index file name?
	If Len(Index_File_Name.Value) > 0 Then

		'Yes. Did the user specify an index file stylesheet?
		If Len(Index_XSL_Stylesheet.Value) < 1 Then

			'No, throw an error
			DisplayInputError "An Index XSL stylesheet was not specified","Index_XSL_Stylesheet"
			VerifyInput = False
			Exit Function

		Else

			'Yes. Does the stylesheet exist?
			If Not oFileSystem.FileExists(Index_XSL_Stylesheet.Value) Then

				DisplayInputError "Index XSL Stylesheet """ & Index_XSL_Stylesheet.Value & """ does not exist","Index_XSL_Stylesheet"
				VerifyInput = False
				Exit Function

			End If

		End If

	End If

	'Did the user specify an XSL stylesheet?
	If (Len(XSL_Stylesheet.value)) < 1 Then

		'No, throw an error
		DisplayInputError "No XSL stylesheet was specified.","XSL_Stylesheet"
		VerifyInput = False
		Exit Function
		
	Else

		'Yes.  Does the stylesheet exist?
		If Not oFileSystem.FileExists(XSL_Stylesheet.value) Then 

			'No, throw an error
			DisplayInputError "XSL stylesheet """ & XSL_Stylesheet.value & """ doesn't exist.","XSL_Stylesheet"
			VerifyInput = False
			Exit Function

		End If

	End If


	'Did the user specify a results directory?
	If Len(Results_Directory.Value) < 1 Then

		'No, throw an error
		DisplayInputError "No Results directory was specified.","Results_Directory"
		VerifyInput = False
		Exit Function

	Else
		
		'Yes. Does the directory exist?
		If Not oFileSystem.FolderExists(Results_Directory.Value) Then

			'No, throw an error
			DisplayInputError "Results Directory """ & Results_Directory.Value & """ does not exist","Results_Directory"
			VerifyInput = False
			Exit Function

		Else

			'Yes. Is there a trailing slash?
			If Right(Results_Directory.Value,1) <> "\" Then

				'No, add one
				Results_Directory.Value = Results_Directory.Value & "\"

			End If

		End If

	End If

	'Did the user specifiy a results extension?
	If Len(Results_Extension.Value) < 1 Then
		
		DisplayInputError "A results file extension was not specified.","Results_Extension"
		VerifyInput = False
		Exit Function

	Else

		'Yes, is there a leading dot?
		If Left(Results_Extension.Value,1) = "." Then

			'Yes. Get rid of it.
			Results_Extension.Value = Right(Results_Extension.Value,Len(Results_Extension.Value) - 1)

		End If

	End If

	'If we haven't errored out by now...
	VerifyInput = True

End Function


Sub Terminate()

	'Clean up the configuration XML object
	'Set oSavedConfigs = Nothing

	'Write the termination note
	WriteToLog "Terminating at " & Now()

End Sub

	
Sub Transform_Button_onclick

	'Log the start time
	dStartTime = Now()

	'Clear the error files and summary
	Activity_Log.Value = ""

	If Not VerifyInput() Then

		Terminate()
		Exit Sub

	End If

	'Disable the text fields and the transform button
	ChangeInputStatus(True)

	'Make sure any error alerts have been cleared
	ClearInputBackgrounds

	'If we're logging, scroll down to the Activity Log
	If LogActivity.Checked = True Then

		Activity_Log_Bookmark.ScrollIntoView

	End If

	Set oXSL = CreateObject("MSXML.DOMDocument")
	WriteToLog "Created XSL object"
	oXSL.Load XSL_Stylesheet.value

	If oXSL.ParseError <> 0 Then

		WriteToLog "XSL PARSE ERROR: " & oXSL.ParseError.Reason
		SetActivityLogBackground "yellow"
		Terminate()
		Exit Sub

	End If
	
	WriteToLog "Loaded XSL Successfully"
	WriteToLog ""
	
	Set oXML_Directory = oFileSystem.GetFolder(XML_Directory.Value)
	WriteToLog "Located XML Directory"
	WriteToLog "Starting File Search"
	WriteToLog ""

	iTotalFiles = 0
	iXMLFiles = 0
	iErrorFiles = 0

	For Each oFile in oXML_Directory.Files

		iTotalFiles = iTotalFiles + 1

		aFileNameParts = Split(oFile.Name,".")

		If LCase(aFileNameParts(1)) = "xml" Then

			iXMLFiles = iXMLFiles + 1

			WriteToLog "Found file: """ & oFile.Name & """"

			Set oXML = CreateObject("MSXML.DOMDocument")
			WriteToLog "Created XML object"

			oXML.Load oFile.Path
			If oXML.ParseError <> 0 Then

				WriteToLog "XML Parse Error: " & oXML.ParseError.Reason
				WriteToLog "Skipping this file"
				WriteToLog ""

				iErrorFiles = iErrorFiles + 1

			Else

				'Add this XML to the index
				sAllTheXML = sAllTheXML & "<fleming_file href=""" & aFileNameParts(0) & "." & Results_Extension.Value & """>" & oXML.xml & "</fleming_file>"


				WriteToLog "Loaded XML"

				sHTML = oXML.TransformNode(oXSL)
				WriteToLog "Transformed Successfully"

				Set oXML = Nothing

				aFileNameParts = Split(oFile.Name,".")
				
				Set oHTMLFile = oFileSystem.CreateTextFile(Results_Directory.Value & aFileNameParts(0) & "." & Results_Extension.Value,True)
				WriteToLog "Created Output File"

				oHTMLFile.Write sHTML
				WriteToLog "Writing to Output File: """ & aFileNameParts(0) & "." & Results_Extension.Value & """"

				oHTMLFile.Close
				Set oHTMLFile = Nothing
				WriteToLog "Closed Output File"

				WriteToLog ""

			End If

		Else

			WriteToLog "Found non-XML file: """ & oFile.Name & """. Skipping."
			WriteToLog ""

		End If
		
	Next

	WriteToLog "No more files"
	WriteToLog ""

	dEndTime = Now()



	'Enable the text fields and the transform button
	ChangeInputStatus(False)

	'Write the summary
	If DateDiff("s",dStartTime,dEndTime) = 0 Then Summary_Seconds.Value = "<1" Else Summary_Seconds.Value = DateDiff("s",dStartTime,dEndTime) End If
	Summary_Total.Value = iTotalFiles
	Summary_XML.Value = iXMLFiles
	Summary_Errors.Value = iErrorFiles
	If iErrorFiles > 0 Then Summary_Errors.style.background = "yellow" End If

	If Len(Index_File_Name.Value) > 0 Then

		'Create the index XML
		Set oIndex = CreateObject("MSXML.DOMDocument")
		oIndex.LoadXML "<fleming_index>" & sAllTheXML & "</fleming_index>"
		WriteToLog "Created index file"

		'Get the index stylesheet
		Set oIndexXSL = CreateObject("MSXML.DOMDocument")
		oIndexXSL.Load Index_XSL_Stylesheet.Value
		WriteToLog "Loaded index stylesheet"
		
		'Write the index file
		Set oHTMLFile = oFileSystem.CreateTextFile(Results_Directory.Value & Index_File_Name.Value & "." & Results_Extension.Value,True)
		oHTMLFile.Write oIndex.TransformNode(oIndexXSL)
		WriteToLog "Transformed index file"
		WriteToLog ""

		'Close the file and clean up
		oHTMLFile.Close
		Set oHTMLFile = Nothing
		Set oIndex = nothing
		Set oIndexXSL = Nothing

	End If

	Msgbox "Complete",64,"Infomation"

	Terminate()

End Sub

Sub WriteToLog(sText)

	'Are we logging?
	If LogActivity.Checked <> True Then
		
		Exit Sub

	End If
	
	'If there's nothing to log, then log a separator
	If Len(sText) = 0 Then

		sText = "--"

	End If

	'Write the value to the log and scroll
	Activity_Log.value = Activity_Log.value & sText & vbcrlf
	Activity_Log.DoScroll("scrollbarPageDown")

End Sub

Sub Clear_Button_OnClick

	XML_Directory.Value = ""
	XSL_Stylesheet.Value = ""
	Results_Directory.Value = ""
	Summary_Seconds.Value = ""
	Summary_Total.Value = ""
	Summary_XML.Value = ""
	Summary_Errors.Value = ""
	Activity_Log.Value = ""
	Results_Extension.Value = ""
	Results_Directory.Value = ""
	Index_File_Name.Value = ""
	Index_XSL_Stylesheet.Value = ""

	ClearInputBackgrounds

End Sub

Sub Load_Button_OnClick

	Saved_Config.style.display = "block"

End Sub

Sub UseSavedConfig(sConfigName)

	Set oConfig = oSavedConfigs.SelectSingleNode("/saved_config/config[name='" & sConfigName & "']")
	
	XML_Directory.Value = oConfig.SelectSingleNode("xml_directory").text
	XSL_Stylesheet.Value = oConfig.SelectSingleNode("xml_stylesheet").text
	Index_File_Name.Value = oConfig.SelectSingleNode("index_filename").text
	Index_XSL_Stylesheet.Value = oConfig.SelectSingleNode("index_stylesheet").text
	Results_Directory.Value = oConfig.SelectSingleNode("results_directory").text
	Results_Extension.Value = oConfig.SelectSingleNode("results_extension").text

	TopOfPage.ScrollIntoView

End Sub

Sub DisplayInputError(sText,sElementID)

	msgbox sText,48,"Input Error"
	WriteToLog "Input Error: " & sText
	WriteToLog ""
	document.all(sElementID).style.background = "yellow"

	If Len(document.all(sElementID).value) > 0 Then

		document.all(sElementID).select()

	Else

		document.all(sElementID).focus()

	End If

End Sub

Sub ClearInputBackgrounds()

	Summary_Errors.style.background = "white"
	XML_Directory.style.background = "white"
	XSL_Stylesheet.style.background = "white"
	Results_Directory.style.background = "white"
	Index_File_Name.style.background = "white"
	Index_XSL_Stylesheet.style.background = "white"

End Sub

Sub SetActivityLogBackground(sColor)

	Activity_Log.style.background = sColor

End Sub

Sub ChangeInputStatus(bDisabled)

	Transform_Button.disabled = bDisabled
	XML_Directory.disabled = bDisabled
	XSL_Stylesheet.disabled = bDisabled
	Results_Directory.disabled = bDisabled
	Results_Extension.disabled = bDisabled
	Index_File_Name.disabled = bDisabled
	Index_XSL_Stylesheet.disabled = bDisabled
	Clear_Button.disabled = bDisabled

End Sub